
:autogenerated:
..
    This file is autogenerated by `generate_custom_files` in conf.py,
    and ought to be generated via building the documentation through Sphinx, e.g.
    with `sphinx-build ./web ./build` from the root directory.

nltk.test.unit.translate package
================================

.. automodule:: nltk.test.unit.translate
    :members:
    :undoc-members:
    :show-inheritance:




**********
Submodules
**********

    .. toctree::
       :maxdepth: 1

       nltk.test.unit.translate.test_bleu
       nltk.test.unit.translate.test_gdfa
       nltk.test.unit.translate.test_ibm1
       nltk.test.unit.translate.test_ibm2
       nltk.test.unit.translate.test_ibm3
       nltk.test.unit.translate.test_ibm4
       nltk.test.unit.translate.test_ibm5
       nltk.test.unit.translate.test_ibm_model
       nltk.test.unit.translate.test_meteor
       nltk.test.unit.translate.test_nist
       nltk.test.unit.translate.test_stack_decoder